
package interfazgrafica3;

import javax.swing.JButton;
import javax.swing.JLabel;

public class Componentes {

    private JLabel jLabelVisualizaContador;
    private JButton jButtonContar;
    private JButton jButtonSalir;   
    private int contador;

    public JLabel getjLabelVisualizaContador() {
        return jLabelVisualizaContador;
    }

    public void setjLabelVisualizaContador(JLabel jLabelVisualizaContador) {
        this.jLabelVisualizaContador = jLabelVisualizaContador;
    }

    public JButton getjButtonContar() {
        return jButtonContar;
    }

    public void setjButtonContar(JButton jButtonContar) {
        this.jButtonContar = jButtonContar;
    }

    public JButton getjButtonSalir() {
        return jButtonSalir;
    }

    public void setjButtonSalir(JButton jButtonSalir) {
        this.jButtonSalir = jButtonSalir;
    }

    public int getContador() {
        return contador;
    }

    public void setContador(int contador) {
        this.contador = contador;
    } 
}
