
package interfazgrafica3;

import java.awt.EventQueue;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;

public class InterfazGrafica3 extends JFrame {
  
    public InterfazGrafica3() {
        setSize(700,500);
        setTitle("Contador de pulsaciones de botón");
        ubicarComponentes();
        setVisible(true);
    }

    
    
    private void ubicarComponentes() {
     
        setLayout(null);
        
        Componentes componentes = new Componentes();
        componentes.setContador(0);
        GestorEventos gestorEventos = new GestorEventos(componentes);
                   // CONFIGURACIÓN JLabel jLabelVisualizaContador
        componentes.setjLabelVisualizaContador(new JLabel("Numero de pulsaciones: "+componentes.getContador()));
        componentes.getjLabelVisualizaContador().setBounds(100,50,300,20);
        add(componentes.getjLabelVisualizaContador());
                   // CONFIGURACIÓN JButton jButtonContar
        componentes.setjButtonContar(new JButton("Contar"));
        componentes.getjButtonContar().setBounds(100,300,100,40);   
        componentes.getjButtonContar().addActionListener(gestorEventos);    // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(componentes.getjButtonContar());
                   // CONFIGURACIÓN JButton jButtonSalir
        componentes.setjButtonSalir(new JButton("Salir"));
        componentes.getjButtonSalir().setBounds(100,400,100,40);
        componentes.getjButtonSalir().addActionListener(gestorEventos);     // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(componentes.getjButtonSalir());
    }
    
    
    
    public static void main(String[] args) {
        EventQueue.invokeLater(new Runnable() {
              @Override
              public void run() {
                 new InterfazGrafica3();
              }
           });          
    }   
}
